@@ -1357,9 +1357,10 @@ perform_initial_sign_in (GoaKerberosProvider *self,
                                                 object);
   g_simple_async_result_set_check_cancellable (operation_result, cancellable);
 
-  g_object_set_data (G_OBJECT (operation_result),
-                     "cancellable",
-                     cancellable);
+  g_object_set_data_full (G_OBJECT (operation_result),
+                          "cancellable",
+                          g_object_ref (cancellable),
+                          g_object_unref);
   g_object_set_data (G_OBJECT (operation_result),
                      "principal",
                      (gpointer)
@@ -1370,6 +1371,8 @@ perform_initial_sign_in (GoaKerberosProvider *self,
                                 (GAsyncReadyCallback)
                                 on_system_prompt_open_for_initial_sign_in,
                                 operation_result);
+
+  g_object_unref (cancellable);
 }
 
 static char *
@@ -1746,21 +1749,12 @@ on_identity_looked_up_to_ensure_credentials (GoaKerberosProvider *self,
 {
 
   GoaIdentityServiceIdentity *identity;
-  GError                     *error;
+  GError                     *error = NULL;
   GoaObject                  *object;
   GoaAccount                 *account;
   const char                 *identifier;
   GCancellable               *cancellable;
 
-  error = NULL;
-  if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (result), &error))
-    {
-      g_simple_async_result_take_error (operation_result, error);
-      g_simple_async_result_complete_in_idle (operation_result);
-      g_object_unref (operation_result);
-      return;
-    }
-
   identity = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (result));
 
   if (identity != NULL && goa_identity_service_identity_get_is_signed_in (identity))
