@@ -105,9 +105,7 @@ goa_kerberos_identity_dispose (GObject *object)
   GoaKerberosIdentity *self = GOA_KERBEROS_IDENTITY (object);
 
   G_LOCK (identity_lock);
-  g_clear_object (&self->priv->renewal_alarm);
-  g_clear_object (&self->priv->expiring_alarm);
-  g_clear_object (&self->priv->expiration_alarm);
+  clear_alarms (self);
   G_UNLOCK (identity_lock);
 
   G_OBJECT_CLASS (goa_kerberos_identity_parent_class)->dispose (object);
@@ -319,6 +317,7 @@ set_error_from_krb5_error_code (GoaKerberosIdentity  *self,
   va_start (args, format);
   literal_message = g_strdup_vprintf (expanded_format, args);
   va_end (args);
+  g_free (expanded_format);
 
   g_set_error_literal (error, GOA_IDENTITY_ERROR, code, literal_message);
   g_free (literal_message);
@@ -529,25 +528,32 @@ static void
 set_expiration_time (GoaKerberosIdentity *self,
                      krb5_timestamp       expiration_time)
 {
+  G_LOCK (identity_lock);
   if (self->priv->expiration_time != expiration_time)
     {
       self->priv->expiration_time = expiration_time;
+      G_UNLOCK (identity_lock);
       queue_notify (self,
                     &self->priv->expiration_time_idle_id,
                     "expiration-timestamp");
+      G_LOCK (identity_lock);
     }
+  G_UNLOCK (identity_lock);
 }
 
 static gboolean
 credentials_are_expired (GoaKerberosIdentity *self,
-                         krb5_creds          *credentials)
+                         krb5_creds          *credentials,
+                         krb5_timestamp      *expiration_time)
 {
   krb5_timestamp current_time;
 
   current_time = get_current_time (self);
 
-  set_expiration_time (self, MAX (credentials->times.endtime,
-                                  self->priv->expiration_time));
+  G_LOCK (identity_lock);
+  *expiration_time = MAX (credentials->times.endtime,
+                          self->priv->expiration_time);
+  G_UNLOCK (identity_lock);
 
   if (credentials->times.endtime <= current_time)
     {
@@ -561,16 +567,15 @@ static VerificationLevel
 verify_identity (GoaKerberosIdentity  *self,
                  GError              **error)
 {
-  krb5_principal principal;
+  krb5_principal principal = NULL;
   krb5_cc_cursor cursor;
   krb5_creds credentials;
   krb5_error_code error_code;
-  VerificationLevel verification_level;
-
-  set_expiration_time (self, 0);
+  krb5_timestamp expiration_time = 0;
+  VerificationLevel verification_level = VERIFICATION_LEVEL_UNVERIFIED;
 
   if (self->priv->credentials_cache == NULL)
-    return VERIFICATION_LEVEL_UNVERIFIED;
+    goto out;
 
   error_code = krb5_cc_get_principal (self->priv->kerberos_context,
                                       self->priv->credentials_cache,
@@ -579,7 +584,7 @@ verify_identity (GoaKerberosIdentity  *self,
   if (error_code != 0)
     {
       if (error_code == KRB5_CC_END || error_code == KRB5_FCC_NOFILE)
-        return VERIFICATION_LEVEL_UNVERIFIED;
+        goto out;
 
       set_error_from_krb5_error_code (self,
                                       error,
@@ -587,7 +592,8 @@ verify_identity (GoaKerberosIdentity  *self,
                                       error_code,
                                       _("Could not find identity in "
                                         "credential cache: %k"));
-      return VERIFICATION_LEVEL_ERROR;
+      verification_level = VERIFICATION_LEVEL_ERROR;
+      goto out;
     }
 
   error_code = krb5_cc_start_seq_get (self->priv->kerberos_context,
@@ -616,7 +622,7 @@ verify_identity (GoaKerberosIdentity  *self,
     {
       if (credentials_validate_existence (self, principal, &credentials))
         {
-          if (!credentials_are_expired (self, &credentials))
+          if (!credentials_are_expired (self, &credentials, &expiration_time))
             verification_level = VERIFICATION_LEVEL_SIGNED_IN;
           else
             verification_level = VERIFICATION_LEVEL_EXISTS;
@@ -661,7 +667,10 @@ verify_identity (GoaKerberosIdentity  *self,
       goto out;
     }
 out:
-  krb5_free_principal (self->priv->kerberos_context, principal);
+  set_expiration_time (self, expiration_time);
+
+  if (principal != NULL)
+    krb5_free_principal (self->priv->kerberos_context, principal);
   return verification_level;
 }
 
@@ -867,7 +876,9 @@ reset_alarms (GoaKerberosIdentity *self)
   GTimeSpan time_span_until_expiration;
 
   now = g_date_time_new_now_local ();
+  G_LOCK (identity_lock);
   expiration_time = g_date_time_new_from_unix_local (self->priv->expiration_time);
+  G_UNLOCK (identity_lock);
   time_span_until_expiration = g_date_time_difference (expiration_time, now);
   g_date_time_unref (now);
 
@@ -988,7 +999,9 @@ on_kerberos_inquiry (krb5_context      kerberos_context,
                            operation->cancellable,
                            operation->inquiry_data);
 
-  if (!goa_identity_inquiry_is_complete (inquiry))
+  if (goa_identity_inquiry_is_failed (inquiry))
+    error_code = KRB5_LIBOS_CANTREADPWD;
+  else if (!goa_identity_inquiry_is_complete (inquiry))
     g_cancellable_cancel (operation->cancellable);
 
   if (g_cancellable_is_cancelled (operation->cancellable))
